/**
 *  标签选择
 */

import React from "react";
import {
  Text,
  TextStyle,
  TouchableOpacity,
  View,
  ViewStyle,
} from "react-native";
import { ScrollView } from "react-native-gesture-handler";
import defaultStyle from "../../configs/defaultStyle";
import Icon from "../icon";

interface Props {
  /**
   *  样式
   */
  style?: ViewStyle;

  /**
   *  类型 slider：滑块   icon:图标
   */
  type?: "slider" | "icon" | "scroll";

  /**
   *  选择项,表示选择了第几项,传null表示什么都不选
   */
  index?: number;

  /**
   *  tab 按钮
   */
  tabItems: { title: string; icon?: number; selectIcon?: number }[];

  /**
   *  选择事件
   */
  onSelect: (index: number) => void;

  /**
   *  文字样式
   */
  textStyle?: {
    selectStyle: TextStyle;
    nomalStyle: TextStyle;
  };

  /**
   *  滑块样式
   */
  sliderStyle?: {
    selectStyle: ViewStyle;
    nomalStyle: ViewStyle;
  };

  /**
   *  tab的图标样式
   */
  iconStyle?: {
    selectStyle: TextStyle;
    nomalStyle: TextStyle;
  };
}

export default function TabBar(props: Readonly<Props>) {
  const {
    style,
    type,
    index,
    tabItems,
    onSelect,
    textStyle,
    sliderStyle,
    iconStyle,
  } = props;

  if (type == "scroll") {
    return (
      <View style={{ height: 40, ...style }}>
        <ScrollView
          horizontal={true}
          showsHorizontalScrollIndicator={false}
          showsVerticalScrollIndicator={false}
        >
          {tabItems.map((tab, i) => {
            let select = i == index;
            let color = select ? defaultStyle.color.mainColor : "#000000";
            let propsTextStyle = select
              ? textStyle?.selectStyle
              : textStyle?.nomalStyle;
            let propsSliderStyle = select
              ? sliderStyle?.selectStyle
              : sliderStyle?.nomalStyle;
            return (
              <TouchableOpacity
                style={{ alignSelf: "stretch", paddingHorizontal: 20 }}
                key={tab.title}
                onPress={() => onSelect && onSelect(i)}
              >
                <View
                  style={{
                    flex: 1,
                    justifyContent: "center",
                    alignItems: "center",
                  }}
                >
                  <Text
                    style={{
                      color: color,
                      fontSize: 14,
                      textAlign: "center",
                      ...propsTextStyle,
                    }}
                    numberOfLines={2}
                  >
                    {tab.title}
                  </Text>
                </View>
                <View
                  style={{
                    height: 2,
                    backgroundColor: color,
                    ...propsSliderStyle,
                  }}
                />
              </TouchableOpacity>
            );
          })}
        </ScrollView>
      </View>
    );
  }

  return (
    <View
      style={{
        height: 40,
        flexDirection: "row",
        justifyContent: "space-around",
        borderBottomColor: "#cccccc99",
        borderBottomWidth: 0.5,
        ...style,
      }}
    >
      {tabItems.map((tab, i) => {
        let select = i == index;
        let color = select ? defaultStyle.color.mainColor : "#000000";
        let propsTextStyle = select
          ? textStyle?.selectStyle
          : textStyle?.nomalStyle;
        let propsSliderStyle = select
          ? sliderStyle?.selectStyle
          : sliderStyle?.nomalStyle;
        let propsIconStyle = select
          ? iconStyle?.selectStyle
          : iconStyle?.nomalStyle;
        if (type == "slider") {
          return (
            <TouchableOpacity
              style={{ alignSelf: "stretch", flex: 1 }}
              key={tab.title}
              onPress={() => onSelect && onSelect(i)}
            >
              <View
                style={{
                  flex: 1,
                  justifyContent: "center",
                  alignItems: "center",
                }}
              >
                <Text
                  style={{
                    color: color,
                    fontSize: 14,
                    textAlign: "center",
                    ...propsTextStyle,
                  }}
                  numberOfLines={2}
                >
                  {tab.title}
                </Text>
              </View>
              <View
                style={{
                  height: 2,
                  backgroundColor: color,
                  marginHorizontal: 10,
                  ...propsSliderStyle,
                }}
              />
            </TouchableOpacity>
          );
        } else {
          return (
            <TouchableOpacity
              style={{
                flexDirection: "row",
                alignSelf: "stretch",
                alignItems: "center",
                paddingHorizontal: 10,
              }}
              key={tab.title}
              onPress={() => onSelect && onSelect(i)}
            >
              <Text
                style={{ color: color, fontSize: 14, ...propsTextStyle }}
                numberOfLines={1}
              >
                {tab.title}
              </Text>
              {tab.icon && (
                <Icon
                  style={{
                    color: color,
                    fontSize: 8,
                    marginLeft: 3,
                    ...propsIconStyle,
                  }}
                  iconCode={select ? tab.selectIcon || tab.icon : tab.icon}
                />
              )}
            </TouchableOpacity>
          );
        }
      })}
    </View>
  );
}
